==> series-1.0.1.tar.gz: series-1.0.1/series/daemon/download.py <==
__copyright__ = """ Copyright (c) 2011-2013 Torsten Schmits

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
"""

import os
import subprocess

import requests

from tek import logger
from tek.tools import resolve_redirect
from tek.config import lazy_configurable
from tek.errors import NotEnoughDiskSpace

from tek_utils.sharehoster import downloader
from tek_utils.sharehoster.errors import RapidshareError

from series.daemon.handler import Handler

@lazy_configurable(daemon=['download_dir', 'torrent_launcher', 'use_torrent'])
class DownloadManager(Handler):

    def __init__(self, queue, commit):
        super(DownloadManager, self).__init__(queue, commit, 5,
                                              'download manager')
        self._min_failed = 0

    def _handle(self, release):
        dispatch = (self._download_torrent if release.is_torrent else
                    self._download_sharehoster)
        dispatch(release)

    def _download_torrent(self, monitor):
        if self._use_torrent:
            cmd = self._torrent_launcher.format(monitor.link)
            logger.info('Executing "{}"'.format(cmd))
            retval = subprocess.call(cmd.split())
            if retval == 0:
                monitor.downloading = True
            else:
                monitor.failed_downloads += 1

    def _download_sharehoster(self, monitor):
        logger.info('Downloading {!s}.'.format(monitor.release))
        try:
            dl = downloader(resolve_redirect(monitor.link),
                            download_dir=self._download_dir)
            dl.retrieve()
            fpath = dl.file_path
            size = os.path.getsize(fpath)
            if size == dl.file_size:
                monitor.download_path = fpath
                monitor.downloaded = True
                self._commit()
            else:
                monitor.failed_downloads += 1
                msg = 'Filesize mismatch in download of {!s}:'
                logger.error(msg.format(monitor.release))
                msg = 'Got {}, expected {}.'
                logger.error(msg.format(size, dl.file_size))
        except NotEnoughDiskSpace as e:
            logger.error(e)
        except RapidshareError as e:
            monitor.down = True
            logger.error(e)
        except requests.RequestException as e:
            monitor.failed_downloads += 1
            logger.error(e)

    @property
    def _candidates(self):
        candidates = filter(lambda r: r.downloadable, self._queue)
        counts = [r.failed_downloads for r in candidates]
        self._min_failed = min(counts or [0])
        return candidates

    def _qualify(self, release):
        return release.failed_downloads == self._min_failed

==> series-1.1.1.tar.gz: series-1.1.1/series/daemon/download.py <==
import os
import subprocess

import requests

from tek import logger
from tek.config import lazy_configurable
from tek.errors import NotEnoughDiskSpace
from tek.tools import sizeof_fmt

from tek_utils.sharehoster import DownloaderFactory
from tek_utils.sharehoster.errors import RapidshareError, ShareHosterError

from series.daemon.handler import Handler


@lazy_configurable(daemon=['download_dir', 'torrent_launcher', 'use_torrent',
                           'min_size'])
class DownloadManager(Handler):

    def __init__(self, queue, commit):
        super(DownloadManager, self).__init__(queue, commit, 5,
                                              'download manager')
        self._min_failed = 0
        self._downloader_fact = DownloaderFactory()

    def _handle(self, release):
        dispatch = (self._download_torrent if release.is_torrent else
                    self._download_sharehoster)
        dispatch(release)

    def _download_torrent(self, monitor):
        if self._use_torrent:
            cmd = self._torrent_launcher.format(monitor.link.url)
            logger.info('Executing "{}"'.format(cmd))
            retval = subprocess.call(cmd.split())
            if retval == 0:
                monitor.downloading = True
            else:
                monitor.failed_downloads += 1

    def _download_sharehoster(self, monitor):
        logger.info('Downloading {!s}.'.format(monitor.release))
        try:
            if not os.path.exists(self._download_dir):
                os.makedirs(self._download_dir)
            dl = self._downloader_fact(monitor.link.url,
                                       download_dir=self._download_dir)
            dl.retrieve()
            fpath = dl.file_path
            size = os.path.getsize(fpath)
            if size < self._min_size:
                monitor.down = True
                msg = 'File smaller than required ({}): {!s}'
                logger.error(msg.format(sizeof_fmt(size), monitor.release))
            elif size == dl.file_size:
                monitor.download_path = fpath
                monitor.downloaded = True
                self._commit()
            else:
                monitor.failed_downloads += 1
                msg = 'Filesize mismatch in download of {!s}:'
                logger.error(msg.format(monitor.release))
                msg = 'Got {}, expected {}.'
                logger.error(msg.format(size, dl.file_size))
        except NotEnoughDiskSpace as e:
            logger.error(e)
        except RapidshareError as e:
            monitor.down = True
            logger.error(e)
        except (requests.RequestException, ShareHosterError) as e:
            monitor.failed_downloads += 1
            logger.error(e)

    @property
    def _candidates(self):
        candidates = [r for r in self._queue if r.downloadable]
        counts = [r.failed_downloads for r in candidates]
        self._min_failed = min(counts or [0])
        return candidates

    def _qualify(self, release):
        return release.failed_downloads == self._min_failed

__all__ = ['DownloadManager']
